#
# spec file for package midori
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major   0
Name:           midori
Version:        v9.0
Release:        bp155.2.16
Summary:        Lightweight Web Browser
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Web/Browsers
URL:            http://midori-browser.org/
Source:         %{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  intltool
BuildRequires:  vala
BuildRequires:  pkgconfig(gcr-3)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libpeas-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
Requires:       ca-certificates
Requires:       ca-certificates-mozilla
Recommends:     %{name}-lang
Recommends:     xdg-utils
Provides:       browser(npapi)
Obsoletes:      %{name}-branding-openSUSE

%description
Midori is a lightweight web browser based on WebKit and GTK+. Its major
features are:

* Tabs, windows and session management.
* Flexibly configurable Web Search.
* User scripts and user styles support.
* Straightforward bookmark management.
* Customizable and extensible interface.
* Extensions written in C and Vala.

%package -n libmidori-core%{major}
Summary:        Midori Library
Group:          System/Libraries
Obsoletes:      libmidori-core1

%description -n libmidori-core%{major}
Midori shared library.

%package devel
Summary:        Development Files for Midori
Group:          Development/Libraries/C and C++
Requires:       libmidori-core%{major} = %{version}
Requires:       typelib-1_0-Midori-0_6
Requires:       pkgconfig(gobject-introspection-1.0)
Recommends:     pkgconfig(vapigen)

%description devel
This package contains development files needed to develop extensions for
Midori.

%package -n typelib-1_0-Midori-0_6
Summary:        Midori Browser -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Midori-0_6
Midori is a lightweight web browser based on WebKit and GTK+.

This package provides the GObject Introspection bindings for Midori.

%lang_package

%prep
%autosetup

%build
%cmake -DCMAKE_INSTALL_PREFIX=/usr ..
%make_build

%install
cd build
%make_install
cd ..
%find_lang %{name} %{?no_lang_C}

# remove redundant doc directory and files
rm -rf %{buildroot}%{_datadir}/doc/midori/

%fdupes -s %{buildroot}%{_datadir}/

%post -n libmidori-core%{major}  -p /sbin/ldconfig
%postun -n libmidori-core%{major} -p /sbin/ldconfig
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc CHANGELOG.md README.md
%license COPYING
%dir %{_libdir}/%{name}
%{_bindir}/%{name}*
%{_datadir}/applications/*.desktop
%{_libdir}/%{name}/*.plugin
%{_libdir}/%{name}/*.so
%{_datadir}/icons/hicolor/*
%{_datadir}/metainfo/*.xml

%files -n libmidori-core%{major}
%{_libdir}/libmidori-core.so.0
%{_libdir}/libmidori-core.so.0.6

%files devel
%{_datadir}/gir-1.0/Midori-0.6.gir
%{_libdir}/libmidori-core.so

%files -n typelib-1_0-Midori-0_6
%{_libdir}/girepository-1.0/Midori-0.6.typelib

%files lang -f %{name}.lang

%changelog
* Tue Jul 30 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 9.0
  * Use OpenGraph images for Speed Dial shortcuts
  * Better support for Javascript popups
  * (Re)store pinned tabs in the session
  * Re-introduce the Trust (certificate) button
  * Avoid key input recursion causing high CPU
  * Close Tab/ Other context menu items
  * Paste and Proceed option in the urlbar
  * Better urlbar suggestion escaping
  * Web extensions: Support for a sidebar action (experimental)
  * Merge app and page menu into one
  * Better focus handling of re-opened and background tabs
  * Show volume icon for tabs playing music
- Updated _service file
- Dropped obsolete zoom-menu.patch
* Mon Mar  4 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added zoom-menu.patch to fix zoom menu entry (issue gh#midori-browser/core#286)
* Sat Mar  2 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 8.0
  * Javascript changes confirmation and prompts use dialogs again
  * Bug fixes in Urlbar completion and focus handling as well as Adblock filtering
  * Headerbar enabled by default only under Budgie, GNOME and Patreon
  * Re-introduced support for `--inactivity-reset`, `-e Fullscreen` and `-e ZoomIn`
  * Initial support for cross-browser web extensions (not exposed in the GUI yet)
  * Builds deps: Glib lowered to 2.46.2, Json-Glib and libarchive are now required
  * Link to the bug tracker from the About dialog
  * Correct handling of external URIs such as apt:
  * Fixed installation path for appdata and plugins
  * Support for building Midori on Android with Gradle
  * Better internal distinction of errors from visiting pages
  * Zoom indicators in the page menu and statusbar features extension
- Switch dependencies to pkgconfig
* Fri Nov 30 2018 maurizio.galli@gmail.com
- Update to version 7.0.git20181130:
  * Fixed YouTube rendering issue due to custom user agent
  * Fixed invisible cursor in text fields
  * Restored behavior of " " and "." in urlbar completion
  * Download/ web notifications for background window/ tab
  * Highlight in toolbar for finished downloads
  * Re-introduced proxy server UX
  * Multiple processes for indivdual tabs
  * Adaptive toolbar layout for smaller screens
- Added Obsoletes
* Thu Nov 29 2018 maurizio.galli@gmail.com
- Update to version 6.0.git20181129:
  * Open external links in default browser in app mode (gh#midori-browser/core#184)
  * Don't consume the tab's focus in event (gh#midori-browser/core#185)
  * Always build menu models from scratch (gh#midori-browser/core#183)
* Tue Nov 27 2018 maurizio.galli@gmail.com
- Update to version 6.0.git20181126:
  * (Re)store last window width and height (gh#midori-browser/core#180)
  * Implement network proxy settings (gh#midori-browser/core#174)
* Mon Nov 26 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Remove Branding packages
* Fri Nov 23 2018 maurizio.galli@gmail.com
- Update to version 6.0.git20181122:
  * Don't add bookmarks UX when in app mode (gh#midori-browser/core#172)
  * Implement notifications for downloads and web (gh#midori-browser/core#175)
  * Hide page and browser actions when window is small (gh#midori-browser/core#171)
  * Go back to using WebKit-provided user agent (gh#midori-browser/core#173)
  * Reduce spacing around delete suggestion button (gh#midori-browser/core#170)
  * Locate system-wide plugins at Config.PLUGINDIR (gh#midori-browser/core#168)
  * Don't block regular key input in app mode (gh#midori-browser/core#167)
  * Always set key regardless of location guess (gh#midori-browser/core#169)
  * Create independent tabs to allow for more processes (gh#midori-browser/core#166)
  * Double-check that extension folder contains Vala sources (gh#midori-browser/core#161)
* Tue Nov 20 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 6.0
  * Revamped Vala-only core based on GTK+3 and WebKit2
  * App based on Gtk.Application, supporting global/ window app menu
  * Tabs on top with a custom stack switcher and Gtk.Stack
  * Url completion with GLib.ListModel and Gtk.ListBox
  * Peas-based extensions, also available in Private Browsing
  * New fullscreen mode with auto-revealing toolbar
- Spec file cleaned and revised to adapt to new version
- Run spec-cleaner
- Removed patch midori-0.5.11-fix-crash-on-startup.patch no longer needed
- Removed patch midori-fix-plugins.diff  no longer needed
- Removed patch midori-fix-vala_0.35.patch  no longer needed
- Removed source file baselibs.conf not needed
- Removed source file midori.1 not needed
* Sat Sep 15 2018 antoine.belvire@opensuse.org
- Fix crash on startup (boo#1108015):
  * Add midori-0.5.11-fix-crash-on-startup.patch.
* Mon Oct 30 2017 okurz@suse.com
- Fix build error on openSUSE:Factory by disabling gtk-doc dependency
* Sun Aug 20 2017 zaitor@opensuse.org
- Replace pkgconfig(gtk+-2.0), pkgconfig(javascriptcoregtk-1.0) and
  pkgconfig(webkit-1.0) with pkgconfig(gtk+-3.0),
  pkgconfig(javascriptcoregtk-4.0) and pkgconfig(webkit2gtk-4.0),
  build against an upstream supported version of webkitgtk. Pass
  - DUSE_GTK3=ON and -DHALF_BRO_INCOM_WEBKIT2=ON to cmake
  conditionally.
- Drop obsolete pkgconfig(unique-1.0) BuildRequires, midori was
  ported away from this in version 0.5.6.
* Wed Apr 26 2017 lazy.kent@opensuse.org
- Add midori-fix-vala_0.35.patch: fix build with vala 0.35+.
* Fri Sep  4 2015 mailaender@opensuse.org
- Add switches for Pantheon/Elementary
* Sun Aug 30 2015 lazy.kent@opensuse.org
- Update to 0.5.11.
  * Add fake theme for built-in icons.
  * Don't truncate long speed dial titles if there's room to
    display them.
  * Fix warnings for -Wformat-security.
  * Ensure vala knows the prototypes of functions it calls, fixing
    pointer truncation in tests.
  * Add unit test to check appmenu/menubar visibility.
  * Fix last known GTK2 entry placeholder text bugs.
  * Make sure that only one of appmenu and menubar are visible
  * initially* as well as when changed.
  * Move adblock icons to hicolor.
  * Limit bookmarks panel callbacks to the lifetime of the panel to
    fix a crash.
  * Fix fallout (broken bookmarks and history panel search) from
    tweaks to GTK2 entry placeholder.
  * Fix property binding to ensure that exactly one of appmenu
    button and menubar is always visible.
  * Skip open-with codepath with abp links, they are internal.
  * Use find_file to locate execinfo.h.
  * Fix middle/ctrl/normal clicking bookmarks (not folders) in the
    bookmarkbar.
  * Add copright header to sanitize_bar.sh.
  * Adblock fixup: Escape . in filter with \.
  * Don't shadow variable uri in midori_browser_save_uri.
  * Switch Adblock icons to 24px color.
  * Always include app menu in toolbar.
  * Fix various mis[sing ]annotations and style issues in GIR.
  * Compile typelib from gir.
  * Fix assert when resetting webapp state after inactivity reset.
  * Clean up handling of double-valued db column in Tabby.
  * Add a comment to explain MidoriBrowser popup callback.
  * Fix warnings printed when right-clicking resize grip between
    location and search entries.
  * Fix menubar warning caused by direct cast instead of `as`.
  * Helper script for setting up bzr with some usefull plugins and
    settings.
  * Stop using Gtk.Entry.max_width_chars.
  * Avoid deprecated SoupServer API with libsoup 2.48.
  * Use unowned in foreach loops in Midori.Window.
  * Use unowned in foreach loops in Midori.Completion.
  * Use unowned with Adblock.Subscription and Element in foreach
    loops.
  * Use unowned strings in foreach loops.
  * Enable openWith in app mode and make it work with view-new.
  * Implement Midori.Window class with toolbar/ headerbar.
  * Drop support for libsoup-gnome-2.4 < 2.37.1.
  * Make search icons for engines work correctly.
  * Move to WebKit2 4.0 which broke ABI.
  * Port to zeitgeist-2.0.
  * Avoid deprecated GtkDialog API with GTK+2 >= 2.22.
  * Title case for "Export Certificate" button.
  * Fix incorrect type of MAX(sorting) in Tabby.
- Disable zeitgeist support.
* Tue Apr 21 2015 aloisio@gmx.com
- Update to 0.5.10
  * use exit instead of return in license script
  * Fix HAVE_GCR guards after GtkPopover port
  * Remove example app and .desktop before creating it in the unit test
  * Fix cache dir path in Adblock and always mkdir tmp
  * Port location action from Granite.PopOver to Gtk.Popover
  * Match https site when user-style is using domain syntax
  * Always disable developer tools on Win32
  * Reimplement Midori.URI.unescape and add various tests
  * Make the inspector resizable with GTK3 by packing into a GtkScrolledWindow
  * Don't build tabs2one in release builds
  * Don't assume GNotification works on Win32
  * update copyright date in About dialog
  * Don't entity-escape history and bookmark results in location completion
  * Only set tabs' error state if errors come from the main frame
  * Implement Paste and Proceed as an action
  * No Gcr on Win for the moment
  * Yet another Speed Dial CSS update:
  * Port bookmark popover from Granite to Gtk.Popover
  * Make application choosers resizable with a sane default size
  * Use GNotification >= 2.40 and use Midori.App API in webmedia
  * Rework mouse button handling in KatzeArrayAction
  * Don't bind :day in HistoryDatabase.query
  * Make GCR mandatory for all builds
  * Update coub support in mediaHerald
  * history-list: Fix gtk+3 build caused by dropping "using Gtk;"
  * Drop all remaining usages of "using *;"
  * Don't open search engines menu when clearing search action
  * Only remove apps in the sidepanel when left-clicking the delete icon
  * Improve robustness of GTK3-compatibility placeholder text fallback
  * Clean up vapi dependency
  * tls_flags from webkit_web_view_get_tls_info need to be 0
  * Don't add failed pages to history
  * Throw error for wrong paramter in Statement.bind
  * Replace NoJS "allow all pages" setting with "allow local pages"
  * Avoid bugs due to race condition in addons delete dialog
  * Calculate transfer progress at regular intervals to fix 0B/s bug and recalcitrant progess bars
  * Fix warnings occurring with EXTRA_WARNINGS
  * Escape parentheses in adblock_fixup_regexp()
  * Use File.query_exist() on win32 when checking for db to attach
  * Handle _NEW_WINDOW_ACTION explicitly to make _blank targets work
  * Fix undefined behavior uint in mouse gestures
  * fix JavaScript keyup event by calling inherited key-release-event handler in MidoriBrowser
  * Inline renaming of speed dials
  * Handle current_size and last_size of Download being equal
  * Add proper copyright headers to element_hider and autosuggestcontrol
  * Add X-GNOME-UsesNotifications to indicate the use of notifications
  * Fix typo in Bookmarks menu UI definition
- Dropped midori-ListStore.patch because it was fixed upstream
* Tue Apr  7 2015 dimstar@opensuse.org
- Add midori-ListStore.patch: Fix "`ListStore' is an ambiguous
  reference between `GLib.ListStore' and `Gtk.ListStore'".
* Fri Nov 21 2014 lazy.kent@opensuse.org
- Update to 0.5.9.
  * Remove dead code from browser and preferences.
  * Build-fix: Make PanedAction's Child.widget public.
  * Fixes tab history undo.
  * Set a placeholder text on the URL entry.
  * Add “Add Bookmark” to menu.
  * Show search menu upon left icon click in location bar.
  * Fix crash when saving with associated resources.
  * Fix webkit2 downloads based on older branch.
  * Don't hide window decorations for Midori-Granite.
  * Connect bookmarks-db singleton correctly to fix menus.
  * Fix some symbol names and transfer annotations in doc comments.
  * Use correct signature for window-state-event handler.
  * Do not overescape page titles in view completion.
  * Make adblock skip non-standard last update metadata strings.
  * Drop deprecated Granite LightWindow used for the Clear Private
    Data dialog.
  * Keep storing the last web media tab played.
  * Allocate CookiePermissionManagerModalInfobar correctly.
  * Make middle clicking reload button duplicate the current tab,
    similar to other browsers.
  * Use network-changed of GNetworkMonitor to reload all tabs if
    network becomes available.
  * Show different messages based on network connectivity.
  * Fix crash when activating the edit menu.
  * Fix “open all in tabs” for bookmarks.
  * Fix a few simple leaks.
  * Don't focus the locationaction when leaving blank pages.
  * Fix leaks of two references to the MidoriApp in Tabby.
  * Compile with valac 0.16 again.
  * Never display about:new in the urlbar.
  * Fix crash right-clicking forms on local pages.
  * Share 'youtube, vimeo, dailymotion' that you are playing in Midori
    using org.midori.mediaHerald.
  * Give the SoupURI a path when checking cookie relevance.
  * Resolve ellipsis and title stripping in completion.
  * Add www. and .com/.country_domain and proceed with
    Ctrl+Enter/Shift+Enter with (readable code).
  * Clean up browser tab/ uri/ title notify.
  * Drop pseudo Granite distinction in completion layout.
  * Fix visibility of SpeedDial, Toolbar, Bookmarkbar context menu
    items.
  * Distinguish between desc file missing and other parsing issues.
  * Use dependencies to clear test folders before execution.
- Remove BuildRequires: appdata-tools (%%{_datadir}/appdata/ belongs
  to filesystem).
- Correct the source URL.
* Thu Sep 11 2014 coolo@suse.com
- add midori-fix-plugins.diff to fix linking in factory
* Thu May  8 2014 lazy.kent@opensuse.org
- Split off a libmidori-core subpackage.
- Install some header files to the -devel subpackage.
- Add baselibs.conf as a source.
- Use %%cmake and %%cmake_install macros.
- BuldReqires appdata-tools for openSUSE >= 13.2.
- Install a manual page (taken from the Debian project).
- Clean up the spec.
* Fri May  2 2014 mailaender@opensuse.org
- update to version 0.5.8
  - Use png icon instead of svg in set_status
  - We must not pass a Cancellable to FaviconDatabase.get_favicon_pixbuf
  - Retain spelling suggestion menu items from WebKit
  - Properly guard usage of gtk3 get_style_context
  - Mimic the look of Granite.DynamicNotebook when compiled with –enable-granite.
  - Fix X11 lib underlink in midori-core
  - Fix bookmarkbar bookmark click not opening links
  - Use sanitized app URI as wm_classname/ StartupWMClass
  - Make trunk build with WebKit2 again
  - Fix for incorrect tstamp for background tabs
  - Don't declare sorting doubles are nullable and print values when database tracing is enabled
  - Correctly apply saved entry state and treat urlbar as a regular editable item
  - Add missing conditional includes for granite flavoured build
  - Open URIs dragged on tab label or new tab button
  - Small adblock bugfixes
  - Work around GTK3's hard-coded minimum stackswitcher button width
  - Fix building with mingw packages from fedora 18
  - Set page title as basis for print filename
  - Rename notes inline
  - Use EXTRA_WARNINGS option when building for windows
  - Drop forgotten clutter init and obsolete header declarations
  - Rework history-step handling and make it work again
  - Port Tabby to DatabaseStatement API
  - Replace bookmark stracing with generic profiling in Midori.Database
  - Port autocompleter test to async job
  - Finishing touches for Adblock
  - Add filters and defaults
  - Implement and use ContextAction.escaped
  - printf URI in show_message_dialog for download error
  - Improve docs and GIR annotations for KatzeItem, KatzeArray, and MidoriWebSettings
  - Drop redundant TabNew from compact menu and put button in Tab Panel
  - Fix loading file pages
  - Implement Send Page Link by Email
  - Use GtkStackSwitcher with GTK+ >= 3.10
  - Implements context popup menu on menu entries of bookmark bar and bookmark menu.
  - Fix building with newer mingw versions
  - Display locationbar suggestions in the correct order
  - Don't bother adblocking internal pages and favicons
  - Don't use trailing comma on last list element in Adblock tests
  - Rewrite Adblock more modularly, add Whitelist support
  - Add support of DragonFlyBSD
  - Change tooltips of Reload and ReloadStop actions while shift modifier is pressed
  - Implement Midori.Database.attach method
  - Allow :memory: as folder to make schema detection work
  - More robust app/ profile creation
  - Add helper callbacks to modify bookmark's tree store with unneded access to bookmarks db
  - Implement more flexible fallback behavior for Cookie Permissions
- changes from version 0.5.7
  - Modify actions and internal items in browser without changing settings
  - Delay tab loading after Midori crashed
  - Uncomment failing assertions about view_source in tab test
  - Fallback to about:home if startup is anything but blank
  - Don't try to create formhistory database if config_dir is NULL
  - Handle url arguments for blank sessions
  - Execute commands given at start time
  - Introduce high-level prepare/ DatabaseStatement API
  - Drop unused GraniteClutter-based animation support
  - Drop uncommented contractor support
  - Drop deprecated StaticNotebook used in KatzePreferences
  - Introduce notebook class converging separate implementations
  - Work around symbol relocation issue old version of gcc present on Ubuntu LTS
  - NULL-check treeview in midori_search_action_get_editor
  - Adjust CMakeList .ico check to not skip nojs icons
  - Enable sidepanel in private mode
  - Move Preferences menu entry above About
  - Set minimum value of 0 on spin button for maximum cache size
  - Give NextForward its own label for toolbar editor
  - Correctly disable favicon database in app and private mode
  - Change preferences to refer to proxy address as a “URI” (not “hostname”)
  - Add close tabs to right feature
  - Allow printing without confirmation dialog on kiosk setups
- changes from version 0.5.6
  - instead of creating devpet status icon on extension load, create it only to show new messages
  - Open speed dial or homepage according to preference
  - handle tab duplication
  - Add copyright note to appdata file
  - Tweak searching for resources when running from build folder
  - Swap NULL-check with main frame check
  - Use correct signal when clearing the trash
  - Hide WebGL preference if it is unavailable
  - Remove stored popup sessions from the database
  - Check all browsers for opened sessions and whether they're popups
  - removed unused preference dialog and related code
  - Fix check for found valac and mention VALAC variable
  - Fix autoscrolling if page contains a frame with our custom error page
  - Don't use context-menu signal in WebKitGTK+ < 1.10.0
  - Fix building on Ubuntu 12.04
  - Reset item ids when re-importing bookmarks
  - Check path being NULL in export before trying to inspect it
  - restore the last closed sessions if no session is opened
  - Cast WebKitDOMHtmlElement for getting source content
  - Use font-set signal and font family for GTK+ 3.2 font chooser
  - add function to view dom source
  - remove unused variable
  - Resolve compiler warnings in current trunk
  - Update win32-release script for cmake, move unused docs/scripts to old folder
  - Try to handle previous runs of cmake in configure wrapper
  - Correct view source assertions in tab unit test
  - Build fix: found undeclared in midori_bookmarks_db_remove_item_recursive
  - Cache bookmark items to avoid their recreation on database reads
  - allow “view source” on about pages
  - Enable old target policy on cmake < 2.8.8
  - Re-arrange data file installing to be more explicit
  - option to modify the number of tabs which will be restored in each idle callback
  - Implement MidoriBookmarksDatabase class by inheritence from MidoriDatabase
  - Ensure tab spinners update as often as the menubar spinner to avoid desync
  - Use tabby sorting increment when importing session.xbel tabs
  - Only install config files to /etc if prefix equals /usr
  - handle urls as argument when starting midori
  - Make tabby compile with Webkit2
  - Drop waf build system and provide cmake-based “configure” script
  - midori_panel_action_activate_cb forgot to update the action group
  - Fixes bug where certificate Security overlay failed to close
  - handle tab movement
  - add tab sorting
  - Untangle implicit GTK+3 for Granite and WebKit2
  - Allow running test under debug tools with cmake
  - Install config files to /etc when install prefix is /usr
  - Add missing PO_FILES argument to GETTEXT_PROCESS_PO_FILES
  - Add USE_APIDOCS to build API docs with CMake
  - Rasterize SVG to PNG with rsvg-convert
  - fix bookmarks test regression after fix-1179200-4
  - Add CMakeLists.txt for config directory
  - Install mo files in locale dir
  - don't change uri/title if the tab isn't loaded
  - use a separate signal to store the tab title
  - Check if execinfo.h header exists on BSD
  - fix endless loop in Midori.Database.init
  - Use destructive-action style class in ClearPrivateData
  - Initialize priv→element to avoid crash when freeing
  - Introduces KatzeArray::update-item to handle metadata changes
  - Refactor excuting schema from file into a function
  - Use stock as string in liststore
  - Drop needless (and wrong) HAVE_LIBNOTIFY in preferences
  - Flip horizontal position of the overlay when hit by the mouse
  - Add Midori.URI.get_base_domain and use it in NoJS
  - Introduce Midori.Database and use for history and tabby
  - ctrl+shift+w should trigger a delete-event
  - Implement dialog windows opened via javascript
  - Make get_res_filename work with different hierarchies
  - fix check for new database
  - Speed up session import
  - Import tab title from old sessions
  - Separate CFLAGS for C and add missing HAVE_
  - Install top-level text files and FAQ html/ css to doc dir
  - Provide and install .appdata.xml file for app stores
  - Move bookmarks db handling to midori-bookmarks-db
  - Add XSS to OPTS_LIBRARIES
  - Update condition for UBUNTU_MENUPROXY to work on Saucy
  - Introduce tabby, the new session manager
  - Fix typo in katze_item_set_meta_integer call
  - Allow bookmark bar update on additions resulting from imports
  - Re-work midori_array_query_recursive to not include folder items twice
  - Fix syntax of icon sizes passed to foreach
  - Add bzr revision number to version if available
  - Unify nojs and cookie policy dialogs, make policy changeable within the list
  - Drop all G_ENABLE_DEBUG guards
  - Add -g to CFLAGS to enable debugging symbols
  - Adjust cmake build for Win32
  - Implement CMake build setup
  - Port MidoriApp from Unique/ sockets to GApplication
  - New signal about-content to provide content for about uris
  - Check if browser is NULL in midori_view_get_tab_menu to prevent a crash. Fixes bug #1215652.
  - Ensure proxy setting widgets callbacks don't outlive the widgets themselves
  - Fix webkit2 build error
  - Show the bookmarks import location combobox.
  - Rename internal completion URLs to avoid confusion
* Sat Aug 17 2013 gber@opensuse.org
- update to version 0.5.5
  - fix name and text fields inversion in XBEL folder import
  - correct packing of cookie and nojs permission dialog.
  - don't set tab title/special when a non-main frame displays an
    error
  - revise "cookies" debug output, merge expiry check and disallow
    revival of old cookies
  - drop now unused cgit module.xml file
  - use SoupProxyResolverGnome unconditionally and disable
    prefetching if proxy is active
  - win32: Hide gui for profiles in webapp manager, as they are
    currently broken on Windows
  - win32: support additional mouse buttons for going back/forward
    in history
  - enrich app error messages with filenames
  - fix segfault if url contains " %%00"
  - replace 'Run as app' in bookmark dialog with 'Create launcher'
  - split config files and install from folders recursively
  - implement GTK+ theme switching via Preferences (Win32)
  - enable set_disk_cache_directory with WebKit2
  - introduce Midori.ContextAction and refactor page menu from
    scratch
  - define large dialog icon size relative to dialog icon size
  - extension Devpet which shows error messages and backtraces in
    systray
  - webKit2 cookie support
  - check the hit test result for editable to see if , should
    search
  - use SoupCookieJarSqlite and drop KatzeHttpCookies(Sqlite)
  - show folder tree when editing bookmarks
  - handle double value in _midori_browser_activate_action
  - add privacy preferences in web app mode
  - escape parentheses in adblock_fixup_regexp
  - introduce object oriented API for access to History Database
  - allow rss feeds with version 0.92
  - rename History completion to Bookmarks and History
  - don't show rss feed icon on twitter, underlying API was retired
  - read apps/ profiles from folder, leave launchers separate
  - fill in bookmark folder attributes in bookmarkbar populate
* Fri Jul 26 2013 gber@opensuse.org
- update to version 0.5.4
  - refactor history step and allow multiple title updates
  - call midori_browser_connect_tab with correct type
  - don't add HistoryCompletion if there's no history
  - restore reload button icon in error pages
  - don't insert folders into the log
  - if an url is specified the fallback url should not be loaded
  - fixed crashes when closing a loading tab + granite's tab moving
  - test if plugins are redundant instead of skipping them all
  - avoid selecting bookmark uris that begin by 'javascript:' for
    completion
  - set FOREIGN_KEYS pragma on db initialization
  - implement a default zoom level preference
  - fix tautological use of G_MAXINT with enum
  - take current selection into account for bookmark folders when
    adding/editing bookmark
  - improve error page visuals, show suggestions on network errors
  - bump vala to 0.16.0
  - downgrade glib requirement to 2.32.3 to re-enable building
    under Ubuntu 12.04 (LTS)
  - bump glib2 version to 2.32.4
  - improve and unify thumbnail generation
  - omit speed dial and blank pages from view completion
  - makes the elements of the speed dial non-selectable
  - use NULL-safe comparison in katze_item_icon_loaded_cb
  - drop non-DOM style sheet injection code path
  - clean small leftovers from GTK and WebKit version bumps
  - bump GTK+ requirement to 2.24 and drop support for earlier
    versions
  - check for app mode to set browser icon instead of readonly
  - escape square brackets in adblock_fixup_regexp
  - fix showing (sub)folders in bookmarkbar
  - bump WebKit requirement to 1.8.3 and drop support for earlier
    versions
  - set menu on dynamic notebook tab
  - do not run toolbar editor's GtkDialog in its own main loop by
    prevent calling gtk_dialog_run(). Instead just set the
    GtkDialog modal and show it
  - remove unnecesary harmful code from tab_switched_cb
  - fix segfault when deleteing tabs with history list
  - specify int64 id item as a string in bookmark remove/update
    queries
  - distinguish between box and event box in the tab label when
    colouring tabs
  - show visual feedback when hovering over items in bookmark panel
  - replace INSTALL/ HACKING with exported Contribute wiki page
  - delete tabs from history list with Del
  - check brightness of backgroung color when deciding foreground
    color of given tab
  - clean launcher filenames, double-click to open and delete
    button
  - avoid declaring browser twice within the same function
  - add ./waf --update-pot
  - fix memory leak introduced in r6184
  - use old function name g_dbus_generate_guid for old valac
  - move Import and Export into menu Bookmarks
  - collect multiple download notifications within a minute
  - fix segfault when right clicking on a web view
  - make libnotify mandatory except on Windows
  - remove the rather unnecessary ./waf --run feature
  - send a notification after creating a launcher
  - ambiguous 'Open as App' context menu item was removed
  - apply label color to label rather than event box
  - store data of app mode based on URL in
    ~/.local/share/midori/apps
  - split colorful tabs code into helper functions and add unit
    tests
  - fix History List memory leak  when closing Midori window
  - replace .gitignore with a .bzrignore
  - always define GCR_VERSION in GTK+2 build
  - fix bookmarks dialog rename regression introduced in r6167
  - drop check for gcr-3-gtk2 which isn't being maintained
  - scrap unneeded background variables in location renderer
    callbacks
  - title case and proper packing in bookmark dialog
  - delete PO files Launchpad spewed into root directory when it
    couldn't find po/*.pot file
  - issue a warning when trying to use MIDORI_DEBUG while running
  - update dates to 2013 to fix bug #1167075
* Fri May 17 2013 gber@opensuse.org
- update to version 0.5.1
  - fix mouse gesture regression breaking context menu
  - fix --run command line switch by midori_paths_init
  - fix bug in size calculation for the history list popup
  - handle diagnostic dialog argument in running instance
  - fix feed panel default value crash
  - ensure existence of the applications directory
  - fix download tooltip crash and extend test case
  - integrate user interaction exploit demo in about:
  - don't convey loading or progress on special pages
  - address missing NULL checks and dead code found by clang
  - no security window for blank pages, but a search icon
  - introduce UI for created apps/ launchers: Web App Manager
  - add custom-title setting to override browser title
  - add a Gtk.Entry to --plain mode for entering URLs
  - deprecate middle_click_opens_selection in favour of
    gtk-enable-primary-paste
- dropped obsolete midori-fix-storing-uint64-in-pointer.patch
* Wed Apr 17 2013 gber@opensuse.org
- replace midori-work-around-vala-storing-uint64-in-pointer.patch
  with midori-fix-storing-uint64-in-pointer.patch which contains an
  actual fix
* Thu Apr  4 2013 gber@opensuse.org
- update to version 0.5.0
  + store --execute arguments in string array
  + prevent overlay frame from being caught by show_all
  + unconditionally show Toolbar Style preference
  + duplicate current URI when reloading Midori.View
  + update tabs being closable on setting change in Granite
  + check default_search before setting SearchAction default
  + populate application chooser button in idle
  + bail out of completion resizing if cell height is 0
  + pass proxy to bookmark dialog when editing via menu
  + tweak bookmark dialog, button to buttons, toggles side by side
  + move 'Flash windows' option into History List
  + use light window for Clear Private Data with Granite
  + use GtkFontButton with filter func with GTK+ 3.2
  + implement 'Run in debugger' button in diagnostic dialog
  + add Win32 work-around to History List for modifiers
  + make toolbar drag/ drop work in GTK+3
  + check if active form element is input before getting search
    text
  + implement direction-based mouse gesture configuration
  + implement mouse movement, load-failed, crashed, search in
    WebKit2
  + add 'Show last crash log' button to diagnostic dialog
  + make invalid actions fail; exit on error in new process only
  + accept setting=value and extension=true/ false in --execute
  + merged cookie permissions as of 2013-03-08
  + gray out webGL preference if context is unavailable
  + use browser API to Close Other in view menu item
  + fix periods to ellipsis in Custom/ Customize Shortcuts
  + support Colorful Tabs in History List
  + add Midori.Tab.fg/ bg_color and Midori.View.set_colors
  + fix word-wrap, #decription and #message in about.css
  + set view scroll policy to Never to avoid flickering
  + use XDG_RUNTIME_DIR for temporary files
  + build Vala and C parts of core separately
  + don't provide default value for enable-scripts
  + respect Open new pages: window for Web Search and Open Image
  + enable-javascript in WebKit1/ 2, macro for (Web)Settings
  + fix MIDORI_*_VERSION to be integers
  + fix .desktop file validation unit test and fix errors
  + 'New tab behavior' preference: about:dial/ new/ search/ home
    alias URLs
  + use stripped down XBEL variant for session and trash
  + allow any proxies supported by libproxy; list supported types
    in preferences
- replaced midori-fix-desktop-files.patch with awk script
* Fri Mar  8 2013 gber@opensuse.org
- update to version 0.4.9
  + let non-Granite security window behave like a window
  + disable Contractor support in Granite for now
  + use cache_dir_for_reading in about:paths
  + strip LRE to prevent it from begin saved to disk
  + enable stripping 'referer' by default
  + fix crash on closing Adlock preferences dialog
  + bail on unset title in completion, fixing strchr urlbar crash
  + manage cookies accept policy per domain - not installed by
    default
  + don't store/ load stock:// icons for special pages
  + drop KatzeScrolled in favour of GTK+ 3.4 touchscreen support
  + write XBEL safely to prevent loss on eg. full disk
  + omit nspluginwrapper Netscape plugins from extensions
  + add --debug/ -g switch to run Midori in gdb
  + list versions from about:version in --version
  + work in progress --enable-webkit2 option enabling WebKit2/
    GTK+3
  + rename menu _Window to _Tabs
  + update Easylist subscription URL for Adblock
  + stop redundant tab numbering when adding
  + allow feed panel webview widget to shrink.
  + don't search for place holder text on cookie list rebuild
  + add 'Google Translate (gt)' as a search engine
  + default external Download Manager to "fetch" on FreeBSD
  + drop GCC-version specific -Wno-unused-but-set-variable
  + change X-Ayatana-Desktop-Shortcuts to Actions
- dropped obsolete midori-fix-docdir.patch
* Tue Feb 19 2013 gber@opensuse.org
- added midori-fix-docdir.patch in order to fix a hardcoded docdir
  that breaks readable view (lp#1130297)
* Wed Feb  6 2013 gber@opensuse.org
- update to version 0.4.8
  + fix un-delaying of tabs
  + fix compilation with GLib 2.30
  + fix error handling in extensions
  + retain selection in urlbar when switching tabs
  + fix missing right-click menu on NextForward button
  + hide error page button if buttons have no images
  + rework URL completion: suggest open tabs
  + always highlight matches in inline search
  + pantheon: Only show private launcher in search
  + granite: Fix notebook, require 0.2, drop _about_dialog_new
  + don't include http(s), file or www. in page title
  + autodetect Twitter RSS feeds
  + adblock: Improve date parsing
  + unit test rework: backtraces, regardless of debugging, wine
  + more accurate version numbers in about:version
  + drop obsolete --log-file command line switch
  + emit inspector attach-window with correct signature
  + fix Netscape plugins opening download dialogs
  + rework path handling and setup in different modes (fix
    segfaults)
  + manage Netscape plugins are individual extensions
  + address gtk_icon_set_render_icon_pixbuf assertions
  + fix renaming in speed dial with spaces in title
  + render completion title/ URL side by side with Granite
  + transparently use Favicon-/ IconDatabase/ file store per WebKit
  + add TabMoveFirst/ Last hotkeys (without defaults)
  + drop Hildon support
  + show URI in 'not responding' dialog
  + query search engine icons when loading, rather than stupid
    guesses
- dropped obsolete midori-fix-build-with-glib-lt-2.32.patch and
  and midori-0.4.2-workaround-vala-bug.patch
- added midori-fix-desktop-files.patch in order to fix the desktop
  files according to openSUSE policy
* Mon Nov 12 2012 gber@opensuse.org
- added midori-fix-build-with-glib-lt-2.32.patch in order to fix
  the build with glib < 2.32
* Sun Nov 11 2012 gber@opensuse.org
- added midori-work-around-vala-storing-uint64-in-pointer.patch in
  order to work around vala trying to store a uint64 in a pointer
  (lp#1053386)
* Thu Sep 20 2012 gber@opensuse.org
- update to version 0.4.7
  + improved download functionality
  * panel and statusbar consistently verify file integrity,
    show size, remaining time and speed of a file
  * an icon and expected file size are displayed before saving a
    file
  * external download managers are available in the preferences
  * the origin of the file is clearly visible in order to counter
    phishing sites which fake downloads
  * optionally whole websites can now be saved including any
    images, scripts and other resources
  + SSL errors are now fatal by default and the colorful URL bar
    has been removed
  + GCR support has been added allowing detailed inspection of
    certificates and sharing of trusted certificates between
    applications using GCR
  + HSTS support was added
  + see the included ChangeLog for a detailed list of all changes
* Tue May 15 2012 gber@opensuse.org
- update to version 0.4.6
  + fix crasher in geolocation infobar
  + fix crasher in about:version on some systems
  + fix crasher opening bookmarks from Unity global menu
  + use WebKitFaviconDatabase as of WebKit 1.8.0
  + use midori-prefixed temp folder in midori_view_save_source
  + fix cancelling downloads with SteadyFlow or Aria2
  + fix crash dialog instead of opening tab in a running window
  + fix page icons in multi-frame sites (gmail, tumbler)
  + distinguish Simplified and Traditional Chinese
  + support go-jump-symbolic
  + handle empty tabs due to download links with a target
  + handle frame load interrupted in the unholy trinity
  + fix libsoup version check and wrong SSL status in location
- drop obsolete midori-fix-broken-libsoup-macros.patch
* Mon Apr 16 2012 gber@opensuse.org
- added midori-fix-broken-libsoup-macros.patch in order to fix the
  broken usage of HAVE_LIBSOUP_* macros (lp#983137)
* Sat Apr 14 2012 gber@opensuse.org
- update to version 0.4.5
  + work around black border around widgets on Win32
  + whitelist direct/ re-directed navigation requests in adblock
  + require Vala 0.14
  + provide geolocation diagnostics in about:geolocation
  + list available about: URLs and app instance name in
    about:version
  + replace illegal characters in download filenames
  + tweak app options on Win32 and use ShellExecuteEx in
    sokoke_show_uri
  + use sokoke_show_uri in midori_browser_download_status_cb
  + external Download manager Steadyflow and Aria2 (with
    cookies)
  + ensure adblock config folder when blocking images
  + use sqlite WAL mode for history if available
  + allow relative -c/ --config path
  + context menus on Back and Forward toolbar items
  + always show the tabbar by default
  + use ubuntu-bug if it exists
  + show inline find while typing and statusbar text in overlay
    with GTK+ 3.2
  + Esc/ closing "downloads still active" should cancel, not
    continue
  + optional Granite support for notebook and bookmark dialog as
    pop-over
  + Ctrl+j to toggle statusbar aka downloads
  + show at most 3 search engines in completion
  + don't replace existing onclick/ blur with autosuggest
  + implement low_memory_profile for FreeBSD and Win32
  + use var in internal javascript, to fix Google apps
  + handle download requests in frames
- correct dependencies
* Wed Apr  4 2012 gber@opensuse.org
- add soft dependency on ca-certificates in order to allow
  certificate verification
* Wed Apr  4 2012 gber@opensuse.org
- add missing build depdendency on pkgconfig(xscrnsaver)
* Sun Apr  1 2012 gber@opensuse.org
- add branding subpackage
- specfile cleanup
* Fri Mar  9 2012 gber@opensuse.org
- update to version 0.4.4
  + disable page cache with < 352 MB RAM
  + display filename in download dialog
  + fix box packing in GTK+3 (in most cases)
  + enable experimental HTML5 fullscreen API
  + harden IPv6 address recognition in location
  + experimental site data policy support (see FAQ)
  + close tabs by middle clicking close button
  + merge cookies and other data in Clear Private Data
  + improve KatzeArrayAction for Unity menuproxy compatibility
  + use GDateTime for history to avoid broken C runtimes
  + add Midori tag to DuckDuckGo default URI
  + rewrite completion popup resizing
  + streamline page icon loading stages and fallbacks
  + disable clipboard work-around for WebKit >= 1.4.3
  + re-word .desktop entry as an action
  + display informative text in private browsing
  + consistent clear icons in entries
  + revised download filename generation
  + add 'Open in Image Viewer' menu item
  + formhistory 2.0 with GDOM support
  + handle javascript: and mailto: links better
  + handle = key in Ukrainian layout better
  + fix bookmark export and deletion of bookmark folders
  + speed dial shortcut re-reordering by DND
* Mon Mar  5 2012 vdziewiecki@suse.com
- add Provides: browser(npapi) FATE#313084
* Wed Dec 28 2011 gber@opensuse.org
- export CCFLAGS rather than CFLAGS, otherwise the waf script will
  add -DG_DISABLE_CHECKS and -DG_DISABLE_ASSERT to CFLAGS and
  thereby disable glib assert statements leading to crashes
  (lp#909005)
* Sun Dec 18 2011 gber@opensuse.org
- update to version 0.4.3
  + implement about:widgets to test rendering
  + fix resizing of inspector by applying a minimum size
  + use dark theme with GTK+ 3 in private browsing
  + use channel-(in)secure-symbolic icons if available
  + use .security-(un)trusted classes with GTK+
  + improve notebook resizing peformance
  + fix tab icons in GTK+3 and don't look for GTK+ jscore
  + use system-wide CA file with libSoup 2.37.1
  + improve cookie manager performance
  + action and tab creation for faster startup
  + fix number of items in trash in private browsing
  + add Cairo version to about:version
  + add X-GNOME-Keywords and X-AppInstall-Keywords to .desktop
  + add easy privacy list to default Adblock filters
  + fully implement speed dial for GTK+3
  + disable box shadows with WebKitGTK+ 1.2.7
  + fine-grained monospace font overriding
  + implement resizing of Location and Search in toolbar
  + don't show empty speed dial shortcuts in-between
  + use Midori's name in midori-private.desktop
  + hide all bars in fullscreen and a menu to Unfullscreen
* Sun Nov 13 2011 gber@opensuse.org
- update to version 0.4.2
  + improve -moz-document parsing in user stylesheets
  + render verified secure sites in green, not yellow
  + version details for extensions built against a different
    release
  + more detailed and more condensed about:version output
  + refresh missing speed dial thumbnails automatically
  + use faster global CSS mechanism for adblock and addons
  + show crash dialog only if there's a session
  + don't complete on a leading space or search token
  + support user stylesheets on about: and file:// locations
  + implement 'Always use my font choices' preferences
  + allow smaller tabs when close buttons are disabled
  + merge 'Closed Tabs' with 'History' in Clear Private Data
  + correctly use user-home and bookmark-new icon names
  + use versioned file speeddial-head-0.4.2.html
  + split proxy server preference into host and port
  + support localized 'next' and 'previous' links
  + implement 'Only accept cookies cookies from sites you visit'
  + fix crash in Add/ Import Bookmark feature
  + fix size of tabs with GTK+ 3
  + detect existing Firefox profiles for bookmark import
  + work-around "omg!" in local directory browsing
  + rework '--run' feature to allow window.open() and
    console.info()
  + automatically clear finnished downloads from the transferbar
  + add 'Create desktop shortcut' to the app menu
  + require GLib 2.22 and libSoup 2.27.90
  + don't register recent files in private browsing mode
  + findbar and speed dial honor close button position
  + use sqlite3-based backend for cookie storage
  + make '--snapshot' create png images with GTK+ 2.20
  + automatically resizing, embossed speed dial, close on hover
- added midori-0.4.2-workaround-vala-bug.patch which works around
  a problem with Vala generating a function for string.replace()
  that potentially returns random data
* Mon Oct 10 2011 gber@opensuse.org
- update to version 0.4.1
  + 'Automatic' identification with quirks
  + Register downloaded files as recent files
  + Use symbolic find and clear icons
  + Drop usage of mootools
  + Install separate Private Browsing shortcut
  + Support dragging tabs out of the window
  + Use feed: to support Thunderbird news reader
  + Re-open closed tabs in private browsing
  + Compare link-fingerprints caselessly
  + Bugfixes
- dropped obsolete midori-0.4.0-fix-underlinking.patch,
  midori-0.4.0-use-dom-api.patch
* Mon Oct  3 2011 gber@opensuse.org
- change midori-0.4.0-fix-underlinking.patch to a version suggested
  by upstream which checks the webkit version
- fix the build on 11.3 by not disabling vala
* Fri Sep 23 2011 gber@opensuse.org
- use midori-0.4.0-fix-underlinking.patch only for >= 12.1
* Wed Sep 21 2011 gber@opensuse.org
- added midori-0.4.0-use-dom-api.patch in order to use DOM API
  instead of private API for retrieving selected text, this fixes
  the build with webkit >= r88621
- added midori-0.4.0-fix-underlinking.patch in order to link
  explicitly against libjavascriptcoregtk
- remove non-standard sections from the desktop file
* Tue Aug  2 2011 gber@opensuse.org
- update to version 0.4.0
  + Provide buttons to choose how to startup after crash
  + Never delay URIs given as command line arguments
  + Space at the bottom of the page: Go to next page
  + Initialize session in app/ private before adding URIs
  + Add 'Last open tabs' option to Clear Private Data
  + Show kinetic scrolling option regardless of Hildon
  + Interpret Shift+Backspace as going forward
  + Advertise SVG images as a supported MIME type
  + Zoom in steps of 10%% and support Ctr+=
  + Integrate Adblock and History List options in list
  + Skip empty lines, ignore subdocument rules in Adblock
  + URL cache, faster JS generator, inline parsing in Adblock
  + Reuse source of webview instead of redownloading
  + Remove the description field from bookmark dialog
  + Add --log-file/ -l switch to log to a file
  + Pass through javascript: URIS from the command line
  + Adjust the preferences dialog
  + Bugfixes
* Mon May 16 2011 gber@opensuse.org
- updated to version 0.3.6
  + Track selected search engine per window
  + Improve preference dialogue size and alignments
  + Validate URIs in Adblock, homepage and bookmarks
  + Support Backspace as Go Back and F5 as Reload
  + Show 'Private Browsing' in Unity Quicklist
  + Ignore Network Cancelled errors
  + Reduce allocations when preparing speed dial
  + Implement geo URI support as per RFC 5870
  + Faster javascript-based JSON import
  + Improve speed dial markup, without scripts
  + Allow Escape to cancel History List
  + Bugfixes
* Mon May  2 2011 prusnak@opensuse.org
- updated to version 0.3.5
  + Remove frame titles from preference dialogue
  + Show search engine icons in completion
  + Add Liferea news aggregator workaround
  + Support libSoup cache + size with WebKitGTK+ 1.3.11
  + No language, no encryption but Mozilla in user agent
  + Support F6, F7, Ctrl+(Shift)+Tab and Tab to complete
  + Strip scheme and www. in completion
  + Render filename as title of patch files
  + Turn location into a plain entry
  + Fix tab panel foreground colours
  + Mask timezone, language and plugins in private mode
  + Add 'Strip referrer details' preference
  + Embed extension list in preferences
  + Remove the Page Holder and Download Manager option
  + Disable prefetching and HTML5 storage in private mode
  + Handle 'Plugin will handle load' error
  + Show access keys next to numbers in link search
  + Introduce --private/ -p command line switch
  + Don't show toolbar preferences if running a DE
  + Show script alerts as infobars
  + Improve URI handling with addon installer
  + Change Ctrl+Q for Quit to Ctrl+Shift+Q
  + Make speed dial faster and mandatory
  + Load speed dial in private browsing mode
  + Show video formats in about:(version)
  + Move speed dial to key file instead of JSON
  + Add Offline Application Cache to Clear Private Data
* Wed Mar 23 2011 gber@opensuse.org
- updated to version 0.3.3
  + Use 60 connections and 6 per host
  + Allow re-ordering of search engines
  + Resurrect right-click button on the panel
  + Page Next finds a and link tags again
  + Always save state when quitting
  + Support MD5 and SHA1 Link Fingerprints
  + Use lock-secure and lock-insecure icons
  + Replace unmaintained docs with FAQ
  + Work around copying bug in WebKitGTK+
  + In doubt always focus page on key press
  + Show transfer speed in tooltips
  + Support x-scheme-handler for GLib < 2.28
  + Improve link search, always require Return
  + Re-order tabs with Ctrl+Shift-PageUp/Down
  + Improve fragment (#) handling
  + Show Netscape plugins in about:version
  + Add Zoom Level combobox to Statusbar Features
  + Improve handling of cookie updates
  + Always show a minimum visible progress
  + Don't limit search engines in completion popup
  + Reflect tab order in the saved session
  + Don't show multiple user addon infobars
  + Provide distribution setting for close on left
  + Export to Netscape HTML format
  + Avoid config update on state changes
  + Always show progress and search engines in location
  + Default to app menu and no menubar
  + Show 'Private Browsing' in window title
  + Uncached reload with Ctrl+Shift+R
  + Bugfixes
* Thu Feb 17 2011 gber@opensuse.org
- call %%icon_theme_cache_post/un
* Tue Feb  1 2011 gber@opensuse.org
- %%post/%%postun are not needed for < 11.4
* Mon Jan 31 2011 gber@opensuse.org
- fix build for < 11.4
* Mon Jan 31 2011 gber@opensuse.org
- updated to version 0.3.0
  + Support libnotify 0.7
  + Copy-friendly URIs with %%20
  + No blocking of typed URLs with adblock
  + Import from Netscape HTML
  + Bookmark im- and export fixes
  + Unit tests cleaned up and updated
  + Correct bookmark and search icon names
  + Better link menu handling
  + Fix Russian keyboard issues
  + Stylesheet parsing improvements
  + Simplify language and panel options
  + Default to DuckDuckGo search
  + No Netscape plugins in extension panel
  + Easy user addon install infobar
- make the -devel subpackage recommend vala
* Wed Jan 26 2011 gber@opensuse.org
- add %%desktop_database_post/%%desktop_database_postun for
  x-scheme-handler
* Sat Jan 15 2011 gber@opensuse.org
- do not require but recommend -lang subpackage
* Fri Dec 24 2010 gber@opensuse.org
- require -lang subpackage
* Fri Dec 24 2010 gber@opensuse.org
- split off -devel package
- package HTML help page
- build API documentation
- use and do not override $RPM_OPT_FLAGS
- improved description/summary
- remove unsupported locales
* Wed Dec 15 2010 prusnak@opensuse.org
- fixed filelist
* Wed Nov 10 2010 prusnak@opensuse.org
- updated to 0.2.9
  + Add 'Identify As' to Statusbar Features
  + Don't restrict length of HTTP login passwords
  + Implement Find Links by number with '.'
  + Reflect security in icon tooltip
  + Use GIO to determine special URI schemes
  + Upgrade waf (addresses threading issues)
  + Allow clearing HTML5 databases and form history
  + Add --help-execute command line switch
  + Improve private mode, with search and hotkeys
  + Support no-desktop-files and internal Open With
  + Support x-scheme-handler spec
  + Infobar for location and HTML5 database
  + Optimise cookie storing, reduce wakeups
  + Avoid deprecated GTK+ interfaces
  + Remove console in favour of Inspector
  + Simplify and explain cookie preferences
  + Fix Google Reader incompatibility
* Wed Nov 10 2010 prusnak@opensuse.org
- updated to 0.2.8
  + Re-implement Bookmarks menu and toolbar button
  + Show transferbar even if statusbar is hidden
  + Smart case for inline search while typing
  + Use Alt+Shift+Right instead of Ctrl+Right for Next Page
  + Adding, edit and delete buttons for user scripts/ styles
  + Rename 'Minimize Tab' to 'Show Tab Icon Only'
  + Delete key in completion deletes items
  + Don't show homepage in bookmarkbar
  + Fix crash when using location arrow button
* Wed Nov 10 2010 prusnak@opensuse.org
- updated to 0.2.7
  + Multiple word completion in location
  + Database backed bookmarks
  + Search bookmark panel and drag bookmarks
  + Bookmarks in address completion
  + Removed bookmarks and history from menubar
  + Add 'Minimize New Tabs' and 'Copy Addresses of Tabs'
  + Refactorings and optimisations in the core
  + Adblock compatibility improvements and speedup
  + Changeable speed dial size
* Wed Nov 10 2010 prusnak@opensuse.org
- updated to 0.2.6
  + Show a dialogue when quitting while downloading
  + Render icons in errors/ speed dial properly
  + Fix a build error with API documentation
  + Fix error pages in frames, and a related crash
  + Allow more shortcuts or columns in speed dial
  + Add 'Copy All' button to Console panel
* Fri May 21 2010 prusnak@suse.cz
- updated to 0.2.5
  + Keyboard access in speed dial
  + Panels adapt to system icon style
  + Revamp tab focus handling
  + Use new GTK+ 2.20 spinner (throbber) widget
  + Userscripts and -styles can be (de)activated
  + Warn if trying to download with few space
  + Support right button in Mouse Gestures
  + Add (unfinished) 'External Applications' extension
  + Vala support for extensions and tests
  + Yellow location for valid SSL, red for invalid
  + Render XML as source code
  + Provide tools/midori-dev and check-style scripts
  + Implement MIDORI_ADBLOCK for Adblock testing
  + Fix https URI support in Adblock
  + Change 'Autodetect proxy' into 'Proxy type'
  + Update use of deprecated GTK+ API
  + Implement --blocked-uris for kiosk usage
  + Implement --inactivity-reset for kiosk usage
  + Fix typing with dead keys and NumLock
  + Improve parsing in the Feed Panel
  + Add preference 'Allow scripts to open popups'
  + Spawn web apps and private mode with same executable
  + Base Colourful Tabs on icon colours
  + Add Status Clock extension
  + Resolve hosts before trying a search
  + Allow page icons for https
  + Improve handling of special pages
  + Protect against recursive external URI handlers
* Thu Apr  1 2010 prusnak@suse.cz
- updated to 0.2.4
  + Prevent completion from overlapping
  + Fix tab order when restoring session
  + Ignore accidentally middle click search
  + Implement bookmark export to XBEL
  + Provide scroll hotkeys, default to Vim
  + Store and complete search in location
  + Fix opening externally with multiple windows
  + Only use icons in panel buttons
  + Fix build with different GTK+ versions
  + Omit micro version and arch from ident string
* Thu Feb 25 2010 prusnak@suse.cz
- updated to 0.2.3
  + Implement 'Close other tabs' menu item
  + Use new GTK+ accessors where available
  + Allow searching freely in History panel
  + Re-implement completion based on sqlite
  + Re-implement completion suggestion popup
  + Simplify sqlite use towards efficient calls
  + Move panel icons to the bottom
  + Merge Netscape Plugins and Extensions panels
  + Implement 'about:version' special page
  + Implement 'Preferred languages' preference
  + Improve window raising behaviour
  + Allow Ctrl+Right-click to suppress javascript menu
  + Add 'Open link as web app' in context menu
  + Add 'Block image' menu item to Adblock
  + Location progress and compat code refactored
  + Implement 'Paste and proceed' in location
  + Move DNS prefetching into the core
  + Allow selecting and deleting multiple cookies
  + Support attaching/ detaching web inspector
  + Always enable web inspector
  + --diagnostic-dialog command line switch
  + Faster file existence checks
  + Simplified, faster adblock implementation
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 0.2.2
  + Turn libnotify into a proper build-time dependency
  + Use Ctrl + Return to open tabs from the location entry
  + Support right-click on bookmark menu items
  + Support -e in midori -a and with multiple commands
  + Make Middle click open selection search if needed
  + Make Ctrl+C work as expected again
  + Fix order of History, Trash and Recently opened pages
  + Revise Shortcuts dialogue to fix oddities
  + Perform Form history completion case insensitive
  + Add 'Web Cache' to Delete Private data dialogue
  + Load accels from /etc/xdg if present
  + Improve XBEL format compatibility and performance
  + Fix inline find by correcting key handling
  + Add option to open panels in separate windows
  + Support Portrait orientation in Fremantle
  + Support Hildon MIME and URI handling
  + Check status before caching in Web Cache
  + Show popup menu on news feed icon if needed
  + Support Colourful Tabs with Tab Panel
  + Tweak sqlite and dbus handling for Win32
  + 'Run as web app' and 'Show in toolbar' for bookmarks
  + Add 'Small icons' toolbar style
  + Fix build with Glib < 2.20 and GTK+ < 2.12
  + Add Import bookmarks for XBEL, Opera and RDF
  + Add Open Link in Foreground/ Background Tab menu
  + Allow closing all tabs
  + Hildon file chooser support
* Sat Nov 14 2009 prusnak@suse.cz
- updated to 0.2.1
  + Fix Mouse Gestures to work after activation
  + Explicitly link to X11 to support gold
  + Implement various Hildon specific features
  + Hide the navigationbar in fullscreen
  + Implement permanent storage of form history
  + Support keyboard shortcuts like Ctrl+Tab or "a"
  + Handle SIGHUP, SIGINT, SIGTERM and SIGQUIT
  + Make creation of new windows fast
  + Introduce the Tab History List extension
  + Load icons laziy at startup to speed up startup
  + Introduce a Web Cache extension
  + Refactor and tweak the Preferences dialogue
  + Implement combos to choose external applications
* Wed Nov  4 2009 prusnak@suse.cz
- fix build
* Fri Oct 16 2009 prusnak@suse.cz
- updated to 0.2.0
  + (Kinetic) drag scrolling on touchscreen devices
  + Workaround a speed dial crasher
  + Faster Adblock with element blocking, for all WebKitGTK+ versions
  + Stripped menu, toolbar and tap on hold on Maemo, and 5.0 menu support
  + Add a DNS prefetching extension
  + Better IDN handling
  + Add a form history extension
  + Restore scrolling positions from the session
  + Keep typed address when switching tabs
  + Avoid storing duplicate history items per day
  + Fix multiple duplicate HTTP authentication dialogs
  + Pass mailto: links to the email client
  + Improve context menu with WebKitGTK+ 1.1.15
  + Checkbox "Remember password" in HTTP authentication
  + Fix a crasher when modifying bookmarks
  + Support page icons other than favicon.ico
  + iPhone identity in Network preferences
* Mon Sep 14 2009 prusnak@suse.cz
- updated to 0.1.10
  + Fix freezing when opening multiple windows
  + Revamp Adblock with WebKitGTK+ 1.1.14 API
  + Greatly improve the address completion
  + Always show news feed icon
  + Better handling of feeds in the feed panel
  + Add Gtk+ and WebKit version to the About dialog
  + Improve tab panel and support minimized tabs
  + Implement disabling of extensions in crahs dialog
  + Don't make the web inspector transient
  + Tidy up the Preferences a bit
  + Load default bookmarks and config from /etc
  + Do not use xprop at runtime
  + Use GNOME proxy server if libsoup-gnome is installed
  + Integrate Save As with transfers
  + Save HTTP logins in a text file
  + Support Undo and Redo with WebKitGTK+ 1.1.14
* Wed Aug 12 2009 prusnak@suse.cz
- updated to 0.1.9
  + Preserve navigation history with new tabs
  + Implement clearing private data when quitting
  + Ellipsize and show close icons in the tab panel
  + Allow hiding panel operating controls
  + Integrate Tools with the compact menu
  + Fix User scripts, User styles and Plugins panel
  + Remove the bookmarkbar popup
  + Add New Tab to the tab context menu
  + Implement minimizing tabs
* Thu Jul 23 2009 prusnak@suse.cz
- updated to 0.1.8
  + Initial support for extension unit tests
  + Set a "browser" role on browser windows
  + Support typing search tokens to open websites
  + Fix focus loss when switching search engines
  + Rewrite Netscape Plugins panel backed by javascript
  + Implement a compact menu if menubar is hidden
  + Provide a context menu for tab labels
  + Implement Tab Panel as a tabbar replacement
  + Remember the last active tab
  + Read and write XBEL metadata internally
  + Implement -e, --execute to perform commands
  + Support socket based single instance
  + Move Go button inside the location entry
  + Fix the ident string after Midori updates
  + Bind Alt + n to switching to the n-th tab
  + Revisit conflicting mnemonics
  + Add a Toolbar Editor extension
  + Add a Shortcut Editor extension
  + Implement context menu in the Transfers panel
  + Simplified Extensions and Addons panels with tick marks
  + Fix Mouse Gestures often ignoreing gestures
  + Use one cookie manager model in all windows
  + Support building Midori for Win32
  + Add an entry to specify Fixed-Width font size
  + Implement Save As in the download dialog
  + Use one history model in all windows
* Mon Jun  1 2009 prusnak@suse.cz
- updated to 0.1.7
  + Save the activation status of extensions
  + Catch and ignore mouse buttons meant for horizontal scrolling
  + Improve panel detaching and how panels handle it
  + Add a Feed Panel extension
  + Add a Fixed-width Font Family preference
  + Support spell checking
  + Implement (optional) Speed dial feature
  + Support nicer error pages with WebKitGTK+ 1.1.6
  + Implement middle click to open menu items in tabs
  + Implement -s, --snapshot command line switch
  + Use libnotify (runtime dependency) for finished transfers
  + Add a Go button to the address entry
  + Always append tabs opened via middle/ double click on the tab bar
  + Implement Open new pages in: New window preference
  + Implement inline find with direct '.' and '/' hotkeys
  + Add basic support for @-moz-document in user styles
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 0.1.6
  + Add Delete All to transferbar
  + Show search in context menu
  + Implement 'Default' search engine
  + Show only icons in Statusbar Features
  + Implement Clear private data
  + Support News Feed icon and external aggregator
  + Fix reloading of Not found pages
  + Fixup spaces when middle click opening
  + Fix possibly wrong identificaton string
  + Optionally search engines in completion
  + Optionally Gtk 2.16 entry progress and icon
  + Experimental panel detaching
  + Support external download manager again
  + Implement '-a', '--app' argument
  + Implement '-c', '--config' argument
  + Fix a bookmark saving issue
  + Support data: URIs in the address entry
  + Several performance and memory leak fixes
  + Load cookies idle to accelerate startup
  + Support mailto: links
  + Save tab reordering in the session
  + Add a Cookie Manager extension
  + Fix crashers in Colourful Tabs
* Mon Mar 23 2009 prusnak@suse.cz
- updated to 0.1.5
  + Add a Colorful Tabs extension
  + Support downloading with WebKitGTK+ 1.1.3
  + Load and save settings of extensions
  + Drop internal source view
  + Require WebKitGTK+ 1.1.1, Glib 2.16 and libsoup 2.25.2
* Mon Mar  2 2009 prusnak@suse.cz
- updated to 0.1.4
  + Automatic inline find can be disabled
  + Implement an Encoding menu
  + Add Open all in Tabs for bookmarks and history
  + Bookmarks can be moved to other folders
  + Fix blank page 'loading' and HTTP authentication
  + Display history dates in the local format
  + Allow editing of completion items
* Mon Feb 23 2009 prusnak@suse.cz
- updated to 0.1.3
  + Sidepanel can be aligned on the right
  + Bookmarks can be organized in folders
  + Support find as you type
  + Support international domain names
  + Tweak location completion
  + Provide default search engines
  + Integrate with Maemo if available
  + Implement Mouse Gestures extension
  + Implement a Plugins panel
  + Editing the toolbar via a context menu
  + Introduce Zoom Text and Images preference
* Wed Jan 28 2009 prusnak@suse.cz
- updated to 0.1.2
  + Open new tabs by clicking on the tabbar
  + Refactor and speed up location completion
  + Show a Crash dialog after crashes
  + Dynamically save files when needed
  + Support Back/ Forward mouse buttons
  + Support javascript: bookmarklets
  + Implement Proxy and Identification string
  + Implement cookie storage on disk
  + Remove autotooled build system
  + Add a new Extensions panel
  + Support javascript bookmarklets
  + Implement opening of new windows
  + Display tooltips in Preferences
* Mon Dec  1 2008 prusnak@suse.cz
- updated to 0.1.1
  + Reimplement page holder as an extension
  + Introduce a C extension interface
  + Introduce unit tests for automated testing
  + Implement history based location completion
  + Support the Web Inspector in new WebKit versions
  + Bookmarkbar properly reflects changes
  + Improve overall OS X integration
  + Add a Text Editor Preference
  + Add a Compat sidebar Preference
  + Add an Open external pages in Preference
  + Implement source view and cached favicons with libsoup
* Mon Oct 20 2008 ajorgensen@novell.com
- Update to 0.1.0
  * Customizable toolbar
  * Error pages
  * The beginnings of user documentation
  * Overall various interface improvements
  * History support in the form of a panel and allowing to hide the
    menubar
- Update to 0.0.21
  * If you hide the statusbar Midori will now show the loading
    progress inside the location entry
  * Typing an address in the location and pressing Alt + Enter will
    open the address in a new tab
* Mon Aug 25 2008 ajorgensen@novell.com
- Update to 0.0.20
  * Support for using a single instance (via libunique, not enabled)
  * Support for user styles
  * Extension icon
* Fri Aug  8 2008 ajorgensen@novell.com
- Initial upload (version 0.0.19)
